package com.winhc.bigdata.spark.jobs.chance

import com.winhc.bigdata.spark.utils.BaseUtil
import com.winhc.bigdata.spark.utils.BaseUtil.cleanup

import scala.annotation.meta.{getter, setter}

/**
 * @Author: XuJiakai
 * @Date: 2020/7/9 16:44
 * @Description:
 */

trait CompanyChangeHandle extends Serializable {
  @getter
  @setter
  protected val equCols: Seq[String]

  /**
   *
   * @param rowkey
   * @param oldMap
   * @param newMap
   * @return  rowkey,类型【insert or update】,新数据，更新字段，更新标题，变更标签【1.一般变更，2.风险变更 ...】,业务时间
   */
  def handle(rowkey: String, oldMap: Map[String, String], newMap: Map[String, String]): (String, String, Map[String, String], String, String, String, String)

  def getEquAndFields(oldMap: Map[String, String], newMap: Map[String, String]): (Boolean, String) = {
    val tmp = equCols.map(f => {
      (f, cleanup(newMap(f)).equals(cleanup(oldMap(f))))
    })
    val eq = tmp.map(_._2).reduce((a1, a2) => a1 && a2)
    if (eq) {
      (true, null)
    } else {
      (eq, tmp.filter(!_._2).map(_._1).mkString(","))
    }
  }
}

//土地公示
case class company_land_publicity(equCols: Seq[String]) extends CompanyChangeHandle with Serializable {
  override def handle(rowkey: String, oldMap: Map[String, String], newMap: Map[String, String]): (String, String, Map[String, String], String, String, String, String) = {
    if (oldMap == null) {
      (rowkey, "insert", newMap, "", s"新增某地块公示", "1", "业务时间")
    } else {
      val t = getEquAndFields(oldMap, newMap)
      if (t._1) {
        null
      } else {
        (rowkey, "update", newMap,
          t._2
          , s"更新某地块公示", "1", "业务时间")
      }
    }
  }
}


case class company(equCols: Seq[String]) extends CompanyChangeHandle with Serializable {
  override def handle(rowkey: String, oldMap: Map[String, String], newMap: Map[String, String]): (String, String, Map[String, String], String, String, String, String) = {
    if (oldMap == null) {
      (rowkey, "insert", newMap, "", s"新增一家公司", "1", "业务时间")
    } else {
      val t = getEquAndFields(oldMap, newMap)
      if (t._1) {
        null
      } else {
        (rowkey, "update", newMap,
          t._2
          , s"更新一家公司", "1", "业务时间")
      }
    }
  }
}