package com.winhc.bigdata.spark.udf

import org.apache.commons.lang3.StringUtils
import org.apache.spark.sql.SparkSession

import scala.annotation.meta.getter

/**
 * @Author: XuJiakai
 * @Date: 2020/7/10 13:49
 * @Description:
 */
trait BaseFunc {
  @(transient@getter) protected val spark: SparkSession
  private val pattern = "[^\\u4e00-\\u9fa5a-zA-Z \\(\\)（）.]+".r

  def tyc_split(): Unit = {
    spark.udf.register("tyc_split", (name: String) => {
      if (StringUtils.isEmpty(name)) {
        null
      } else {
        name.split("\t;\t")
      }
    })
  }

  def company_split(): Unit = {
    spark.udf.register("company_split", (name: String) => {
      if (StringUtils.isEmpty(name)) {
        Array("")
      } else {
        pattern.split(name)
      }
    })
  }


  def area_code(): Unit = {
    spark.udf.register("get_province_code", (name: String) => {
      if (StringUtils.isNotEmpty(name) && name.trim.length == 6) {
        name.trim.substring(0, 2)
      } else {
        null
      }
    })
    spark.udf.register("get_city_code", (name: String) => {
      if (StringUtils.isNotEmpty(name) && name.trim.length == 6) {
        name.trim.substring(2, 4)
      } else {
        null
      }
    })
    spark.udf.register("get_county_code", (name: String) => {
      if (StringUtils.isNotEmpty(name) && name.trim.length == 6) {
        name.trim.substring(4, 6)
      } else {
        null
      }
    })
  }
}
